@@ -81,9 +81,9 @@ class MysqlConnect(object):
             _column = self.__cursor.description
 
             _result = [dict(zip([column[0] for column in _column], data)) for data in _data]
-            return True, _result
+            return _result
         except BaseException as _e:
-            return False, _e
+            raise _e
 
     def exec_cmd(self, sql, params=None):
         try:
