@@ -13,8 +13,8 @@ from pyrainsty import connect
 
 def main():
     config = dict(
-        host='121.40.24.251',
-        port=9023,
+        host='121.36.85.248',
+        port=9024,
         user='root',
         password='123456',
         database='storm_monitor',
@@ -25,20 +25,17 @@ def main():
     mc.create_connect()
     mc.close_connect()
     mc.check_connect()
-    state, result = mc.get_data('select * from check_time limit %(limit)s', dict(limit=10))
-    if not state:
-        print(result)
-
+    result = mc.get_data('select * from check_time limit %(limit)s', dict(limit=10))
     print(result)
+
     cursor = mc.get_cursor
     cursor.execute('select * from check_time limit 1')
     data = cursor.fetchall()
     for d in data:
         print(d)
 
-    state, result = mc.exec_cmd('select * from check_time limit 1')
-    if not state:
-        print(result)
+    result = mc.exec_cmd('select * from check_time limit 1')
+    print(result)
 
 
 if __name__ == '__main__':
